@@ -4,4 +4,5 @@ except ModuleNotFoundError:
     import importlib_metadata
 __version__ = importlib_metadata.version(__name__)
 
-from .main import *
+from .main import app
+from . import arg_parser
